==> ochusha-0.4.9.3.tar.bz2: ochusha-0.4.9.3/libmodifiedgtk2/marshal.h <==

#ifndef __modgtk2_marshal_MARSHAL_H__
#define __modgtk2_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOOLEAN (marshal.list:1) */
extern void modgtk2_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:ENUM (marshal.list:2) */
extern void modgtk2_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:ENUM (marshal.list:3) */
#define modgtk2_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (marshal.list:4) */
#define modgtk2_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:POINTER,UINT (marshal.list:5) */
extern void modgtk2_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

G_END_DECLS

#endif /* __modgtk2_marshal_MARSHAL_H__ */

==> ochusha-0.5.tar.bz2: ochusha-0.5/libmodifiedgtk2/marshal.h <==

#ifndef __modgtk2_marshal_MARSHAL_H__
#define __modgtk2_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* BOOLEAN:BOOLEAN (./marshal.list:1) */
extern void modgtk2_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* BOOLEAN:ENUM (./marshal.list:2) */
extern void modgtk2_marshal_BOOLEAN__ENUM (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
                                           const GValue *param_values,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);

/* VOID:ENUM (./marshal.list:3) */
#define modgtk2_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM

/* VOID:INT (./marshal.list:4) */
#define modgtk2_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:POINTER,UINT (./marshal.list:5) */
extern void modgtk2_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
                                                const GValue *param_values,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);

G_END_DECLS

#endif /* __modgtk2_marshal_MARSHAL_H__ */
